@@ -3,10 +3,10 @@
 Basking.io — Python SDK
 - Location Class: handles all functionality related to locations.
 """
-
 import json
 import logging
 from functools import lru_cache
+from typing import Union
 
 import pandas as pd
 
@@ -24,21 +24,13 @@ class Location:
         basking_log_level = logging.getLogger(self.basking.__class__.__name__).level
         self.log.setLevel(basking_log_level)
 
-    def get_adjusted_capacity(self, building_id):
+    def get_adjusted_capacity(self, building_id: str, pandify: bool = False) -> Union[pd.DataFrame, dict]:
         """
         Returns the adjusted capacity at Building level in percentage
-
-        :param building_id: building_id
-        :type building_id: str.
-
-        :return: return get_adjusted_capacity
-
         """
 
-        query, variables = self.basking.graphql_query.get_adjusted_capacity_graphql_query(
-            building_id
-        )
-
+        query, variables = self.basking.graphql_query.get_adjusted_capacity_graphql_query(building_id)
+        data = {}
         result = self.basking.graphql_query.graphql_executor(query=query, variables=variables)
         data_ = json.loads(result)
         if 'message' in data_:
@@ -50,8 +42,11 @@ class Location:
                 data = {}
         else:
             data = {}
-        df = pd.DataFrame(data)
-        return df
+
+        if pandify:
+            return pd.DataFrame(data)
+        else:
+            return data
 
     def get_user_buildings(self, pandify=True):
         """
